import unittest


class TestMoment(unittest.TestCase):
    def test_mean(self) -> None:
        pass

    def test_median(self) -> None:
        pass

    def test_var(self) -> None:
        pass

    def test_skew(self) -> None:
        pass

    def test_kurtosis(self) -> None:
        pass
